==> spip_3.0.22.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Benvenuto @nom@ !',
	'c_accueil_configurer_site' => 'Configurate il vostro sito',
	'c_accueil_configurer_site_texte' => 'Una delle prime cose da fare è dare un nome al tuo sito.
Ora si chiama " @nom@ ". Il nome del sito viene visualizzato nella parte superiore di questa pagina.
Facendo clic, è possibile modificare il nome, ma anche dargli un logo e uno slogan.',
	'c_accueil_publication' => 'Inviare !',
	'c_accueil_publication_texte' => 'Per pubblicare una pagina, è necessario creare un articolo.
È necessario che per creare almeno una rubrica. È possibile farlo nel menu "Modifica" cliccando su "Rubriche".',
	'c_accueil_texte' => 'Siete appena entrati nell’area privata di SPIP.',
	'c_accueil_texte_revenir' => 'Questa pagina mostra l’ultima attività editoriale sul tuo sito.
Puoi visitare questa pagina in qualsiasi momento facendo clic sull’icona home, sulla parte superiore, sotto il tuo nome.',
	'c_article_redaction' => 'L’articolo è in corso di redazione',
	'c_article_redaction_redacteur' => 'L’articolo è in fase di redazione',
	'c_article_redaction_redacteur_texte' => 'Per inviare il tuo articolo per gli amministratori del sito e di altri editori, attraverso il pulsante a lato, cambiare da "in scrittura" a "proposto per la pubblicazione."',
	'c_article_redaction_texte' => 'Per pubblicare questo articolo sul sito pubblico, modificarne lo stato.
Sulla casella a lato, cambiare da "in corso di redazione" in "pubblicato online".',
	'c_articles_creer' => 'Come creare un articolo ?',
	'c_articles_creer_texte' => 'È possibile creare un articolo da questa pagina non appena c’è una rubrica nel vostro sito.
È possibile creare dal menu "Modifica" e poi "Rubriche".',
	'c_job' => 'Lavoro da fare...',
	'c_job_texte' => 'Questa pagina elenca le operazioni di manutenzione che saranno effettuate da SPIP. Queste operazioni vengono eseguite a intervalli regolari o occasionalmente nel caso  di elaborazioni pesanti richiesta dai plugin, come l’invio di email massive.',
	'c_rubrique_publier' => 'Crea un’articolo',
	'c_rubrique_publier_texte' => 'Una sezione è visibile sul sito pubblico
dal momento che essa contiene almeno un contenuto pubblicato, per esempio: un articolo pubblicato.
Quindi creare un articolo. Puoi farlo da questa pagina sotto la descrizione del tuo articolo.',
	'c_rubriques_creer' => 'Crea la prima rubrica!',
	'c_rubriques_creer_texte' => 'Le rubriche sono la struttura di base del sito, è possibile creare elementi ciascuna.
Iniziare con la creazione di una prima rubrica.',

	// E
	'explication_activer_compagnon' => 'L’assistente aggiunge commenti su alcune pagine dello spazio privato per contribuire a rendere SPIP più facile da usare. Vuoi per attivarlo?',
	'explication_reinitialiser_compagnon' => 'I messaggi già visti da un autore non verranno più visualizzati.
Vuoi ripristinare questi messaggi?',

	// L
	'label_activer_compagnon' => 'Attivare l’assistente ?',
	'label_reinitialiser_compagnon' => 'Cancellare i messaggi dell’assistente ?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Bene !',
	'ok_jai_compris' => 'Ho capito !',
	'ok_merci' => 'Grazie',
	'ok_parfait' => 'Perfetto !',

	// R
	'reinitialisation' => 'Reinizializzazione',
	'reinitialisation_ok' => 'La reinizializzazione è stata effettuata.',
	'reinitialiser' => 'Reinizializzare',
	'reinitialiser_moi' => 'Sì, solo quelle che ho già letto',
	'reinitialiser_tous' => 'Si, qualunque sia l’autore',

	// T
	'titre_compagnon' => 'L’assistente',
	'titre_page_configurer_compagnon' => 'Configurare l’assistente'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Benvenuto @nom@ !',
	'c_accueil_configurer_site' => 'Configurate il vostro sito',
	'c_accueil_configurer_site_texte' => 'Una delle prime cose da fare è dare un nome al tuo sito.
Ora si chiama " @nom@ ". Il nome del sito viene visualizzato nella parte superiore di questa pagina.
Facendo clic, è possibile modificare il nome, ma anche dargli un logo e uno slogan.',
	'c_accueil_publication' => 'Inviare !',
	'c_accueil_publication_texte' => 'Per pubblicare una pagina, è necessario creare un articolo.
È necessario che per creare almeno una rubrica. È possibile farlo nel menu "Modifica" cliccando su "Rubriche".',
	'c_accueil_texte' => 'Siete appena entrati nell’area privata di SPIP.',
	'c_accueil_texte_revenir' => 'Questa pagina mostra l’ultima attività editoriale sul tuo sito.
Puoi visitare questa pagina in qualsiasi momento facendo clic sull’icona home, sulla parte superiore, sotto il tuo nome.', # MODIF
	'c_article_redaction' => 'L’articolo è in corso di redazione',
	'c_article_redaction_redacteur' => 'L’articolo è in fase di redazione',
	'c_article_redaction_redacteur_texte' => 'Per inviare il tuo articolo per gli amministratori del sito e di altri editori, attraverso il pulsante a lato, cambiare da "in scrittura" a "proposto per la pubblicazione."',
	'c_article_redaction_texte' => 'Per pubblicare questo articolo sul sito pubblico, modificarne lo stato.
Sulla casella a lato, cambiare da "in corso di redazione" in "pubblicato online".',
	'c_articles_creer' => 'Come creare un articolo ?',
	'c_articles_creer_texte' => 'È possibile creare un articolo da questa pagina non appena c’è una rubrica nel vostro sito.
È possibile creare dal menu "Modifica" e poi "Rubriche".',
	'c_job' => 'Lavoro da fare...',
	'c_job_texte' => 'Questa pagina elenca le operazioni di manutenzione che saranno effettuate da SPIP. Queste operazioni vengono eseguite a intervalli regolari o occasionalmente nel caso  di elaborazioni pesanti richiesta dai plugin, come l’invio di email massive.',
	'c_rubrique_publier' => 'Crea un’articolo',
	'c_rubrique_publier_texte' => 'Una sezione è visibile sul sito pubblico
dal momento che essa contiene almeno un contenuto pubblicato, per esempio: un articolo pubblicato.
Quindi creare un articolo. Puoi farlo da questa pagina sotto la descrizione del tuo articolo.',
	'c_rubriques_creer' => 'Crea la prima rubrica!',
	'c_rubriques_creer_texte' => 'Le rubriche sono la struttura di base del sito, è possibile creare elementi ciascuna.
Iniziare con la creazione di una prima rubrica.',
	'c_sites_creer' => 'Come creare o importare uno sito ?', # RELIRE

	// E
	'explication_activer_compagnon' => 'L’assistente aggiunge commenti su alcune pagine dello spazio privato per contribuire a rendere SPIP più facile da usare. Vuoi per attivarlo?',
	'explication_reinitialiser_compagnon' => 'I messaggi già visti da un autore non verranno più visualizzati.
Vuoi ripristinare questi messaggi?',

	// L
	'label_activer_compagnon' => 'Attivare l’assistente ?',
	'label_reinitialiser_compagnon' => 'Cancellare i messaggi dell’assistente ?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Bene !',
	'ok_jai_compris' => 'Ho capito !',
	'ok_merci' => 'Grazie',
	'ok_parfait' => 'Perfetto !',

	// R
	'reinitialisation' => 'Reinizializzazione',
	'reinitialisation_ok' => 'La reinizializzazione è stata effettuata.',
	'reinitialiser' => 'Reinizializzare',
	'reinitialiser_moi' => 'Sì, solo quelle che ho già letto',
	'reinitialiser_tous' => 'Si, qualunque sia l’autore',

	// T
	'titre_compagnon' => 'L’assistente',
	'titre_page_configurer_compagnon' => 'Configurare l’assistente'
);

?>
